﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEditor;

//This script is responsible for handling the in-editor appearance of entity.cs
[CustomEditor(typeof(Entity))]
public class EntityEditor : Editor {

	//getting target object an casting the interaction type
	private Entity originalScript;
	private SerializedObject originalObject;

	//Serialized properties
	private SerializedProperty entityId;
	private SerializedProperty canBeInteractedWith;

	private SerializedProperty stages;
	private SerializedProperty options;
	private SerializedProperty nodes;

	private SerializedProperty xmlIP;
	private SerializedProperty xmlEP;
	private SerializedProperty xmlIFN;
	private SerializedProperty xmlEFN;

	//Display Messages
	private string st = "Stages are used for story progression. Starting stages can be set via the database. Refer to doc.";
	private string ot = "Options can be displayed to allow players to choose which dialogue path / actions to take.";
	private string nt = "Nodes are a collection of functions that allows NPC / Object interaction.";
	private string mt = "Basic entity configuration.";

	private void OnEnable() {
		
		//Getting entity script and object
		originalScript = (Entity) target;
		originalObject = new SerializedObject (target);

		//Getting properties
		stages = originalObject.FindProperty("stages");
		nodes = originalObject.FindProperty("nodes");
		options = originalObject.FindProperty("options");
		entityId = originalObject.FindProperty("entityId");
		canBeInteractedWith = originalObject.FindProperty("canBeInteractedWith");

		//XML
		xmlIP = originalObject.FindProperty("XMLImportPath");
		xmlEP = originalObject.FindProperty("XMLExportPath");
		xmlIFN = originalObject.FindProperty("XMLImportFileName");
		xmlEFN = originalObject.FindProperty("XMLExportFileName");
	}

	public override void OnInspectorGUI() {

		originalObject.Update();
		EditorGUI.BeginChangeCheck();

		//creating tabs
		originalScript.tab = GUILayout.Toolbar(originalScript.tab, new string[] {"Config","Stages", "Nodes", "Options"});

		//Drawing
		switch (originalScript.tab) {
			case 0:
				EditorGUILayout.HelpBox(mt, MessageType.Warning);
				GUILayout.Space(10);
				EditorGUILayout.PropertyField(entityId);
				GUILayout.Space(10);
				EditorGUILayout.PropertyField(canBeInteractedWith);
				GUILayout.Space(10);
				break;
			case 1:
				EditorGUILayout.HelpBox(st, MessageType.Info);
				GUILayout.Space(10);
				EditorGUILayout.PropertyField(stages, true);
				break;
			case 2:
				EditorGUILayout.HelpBox(nt, MessageType.Info);
				GUILayout.Space(10);
				EditorGUILayout.PropertyField(nodes, true);

				//xml
				GUILayout.Space(30);
				EditorGUILayout.PropertyField(xmlIP);
				GUILayout.Space(10);
				EditorGUILayout.PropertyField(xmlEP);
				GUILayout.Space(10);
				EditorGUILayout.PropertyField(xmlIFN);
				GUILayout.Space(10);
				EditorGUILayout.PropertyField(xmlEFN);
				GUILayout.Space(10);

				//xml import and export
				if (GUILayout.Button("Import XML")) {
					originalScript.XMLImport();
				}

				if (GUILayout.Button("Export XML")) {
					originalScript.XMLExport();
				}

				break;
			default:
				EditorGUILayout.HelpBox(ot, MessageType.Info);
				GUILayout.Space(10);
				EditorGUILayout.PropertyField(options, true);
				break;
		}

		GUILayout.Space(20);

		//Applying changes
		if (EditorGUI.EndChangeCheck()) {
			originalObject.ApplyModifiedProperties();
		}

	}

}
