﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class CameraPositionMonitor : MonoBehaviour {

	//reference
	public static CameraPositionMonitor core;

	//Max and min camera position on x
	public float maxCameraX;
	public float minCameraX;

	public float maxCameraY;
	public float minCameraY;

	[HideInInspector]
	//The status of the camera
	//0 - Free to move || 1 - Free to move on the x axis || 2 - Free to move on the y axis
	public int cameraStatus = 0;
	//Has the camera reached min or max (or none)?
	//0 - None || 1 - Min || 2 - Max
	public int boundary = 0;

	void Update () {
		
		var cam = GameObject.FindGameObjectWithTag("MainCamera");
		var player = GameObject.FindGameObjectWithTag("Player");

		Vector2 camVector = new Vector2 (cam.transform.position.x, cam.transform.position.y);
		Vector2 playerVector = new Vector2 (player.transform.position.x, player.transform.position.y);

		if (camVector != playerVector) {

			var tr = player.transform.position;

			//If the position of the player exceeds x or y limits, act accordingly
			if (tr.x < maxCameraX && tr.x > minCameraX && tr.y < maxCameraY && tr.y > minCameraY) {
				cam.transform.position = new Vector3 (player.transform.position.x, player.transform.position.y, cam.transform.position.z);
				//letting the engine know that the camera is free to move in any direction
				cameraStatus = 0;
				//and that it has not encountered any boundary
				boundary = 0;
			} else if (tr.x < maxCameraX && tr.x > minCameraX) {
				cam.transform.position = new Vector3 (player.transform.position.x, cam.transform.position.y, cam.transform.position.z);
				cameraStatus = 1;
				//Has the camera reached min or max coordinate(s) ?
				if (tr.y > maxCameraY) { boundary = 2; } else { boundary = 1; }
			} else {
				cam.transform.position = new Vector3 (cam.transform.position.x, player.transform.position.y, cam.transform.position.z);
				cameraStatus = 2;
				if (tr.x > maxCameraX) { boundary = 2; } else { boundary = 1; }
			}

			//Used to ensure that the position of the camera is set properly
			if (cameraStatus == 2) {
				if (boundary == 1) { 
					cam.transform.position = new Vector3 (minCameraX, cam.transform.position.y, cam.transform.position.z); 
				} else { 
					cam.transform.position = new Vector3 (maxCameraX, cam.transform.position.y, cam.transform.position.z); 
				}
			} else if (cameraStatus == 1) {
				if (boundary == 1) { 
					cam.transform.position = new Vector3 (cam.transform.position.x, minCameraY, cam.transform.position.z); 
				} else { 
					cam.transform.position = new Vector3 (cam.transform.position.x, maxCameraY, cam.transform.position.z); 
				}
			}
			
		}

	}

	void Awake () {
		if (core == null) {
			core = this;
		}
	}
}

//Tsenkilidis Alexandros - Cination