﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

//This script is responsible for changing cursors
public class CursorChanger : MonoBehaviour {

	//reference
	public static CursorChanger core;

	//a List of all cursors
	public List<cursorState> cursors = new List<cursorState>();

	//active cursor ID
	private int activeCursor = -1;
	private int initialActiveCursor;

	public int normalCursorId;
	public int highlightCursorId;

	[HideInInspector]
	public bool showNormalCursor;

	[HideInInspector]
	public bool showHighlightCursor;

    public CursorMode cursorMode = CursorMode.Auto;
    public Vector2 offset = Vector2.zero;

	
	//Has the cursor changed?
	void Update () {

		//which cursor should be used ?
		if (showNormalCursor) {
			activeCursor = normalCursorId;
		} else if (showHighlightCursor) {
			activeCursor = highlightCursorId;
		} else {
			activeCursor = -1;
		}

		if (initialActiveCursor != activeCursor && activeCursor != -1) {
			initialActiveCursor = activeCursor;

			if (findCursorIndexById(activeCursor) != -1) {
				//changing
				Cursor.SetCursor(cursors[findCursorIndexById(activeCursor)].cursorTexture, offset, cursorMode);
			}
		} else if (activeCursor == -1) {
			//resetting default cursor
			Cursor.SetCursor(null, Vector2.zero, cursorMode);
		}

	}

	public void switchCursor (bool showNormal) {
		if (showNormal) {
			showNormalCursor = true;
			showHighlightCursor = false;
		} else {
			showNormalCursor = false;
			showHighlightCursor = true;
		}
	}

	//save initial active cursor id
	void Start() {
		//setting cursor
		switchCursor (true);
		//setting intial id
		initialActiveCursor = activeCursor;
	}

	void Awake () {
		if (core == null) {
			core = this;
		}
	}

	int findCursorIndexById (int id) {
		var counter = 0;
		foreach (cursorState cursor in cursors) {
			if (cursor.cursorId == id) {
				return counter;
			} else {
				counter++;
			}
		}

		return -1;
	}
}

[System.Serializable]
public class cursorState {
	public int cursorId;
	public Texture2D cursorTexture;

}


//Tsenkilidis Alexadros - Cination