﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

//the library of all items
public class Database : MonoBehaviour {

	public static Database core;

	[Tooltip("A list of all in-game items.")]
	public List<items> items = new List<items>();

	[Tooltip("A list of non-(system)serializable item properties.")]
	public List<itemsMeta> itemsMeta = new List<itemsMeta>();

	[Space(10)][Tooltip("A list of all entities (NPCs and other interactable objects).")]
	public List<entities> entities = new List<entities>();

	[Space(10)][Tooltip("A list of all quests.")]
	public List<quests> quests = new List<quests>();

	[Space(10)][Tooltip("A list of all journal entries (dialogue lines and corresponsing entity names).")]
	public List<journal> journal = new List<journal>();

	[Space(10)][Tooltip("A list of all locations (levels).")]
	public List<locations> locations = new List<locations>();

	[Space(10)][Tooltip("A list of walking sound clips.")]
	public List<stepSound> stepSounds = new List<stepSound>();

	[Space(10)][Tooltip("A list of music clips.")]
	public List<backgroundMusic> music = new List<backgroundMusic>();

	[Space(10)][Tooltip("A list of walking sound clips.")]
	public List<backgroundAmbience> ambience = new List<backgroundAmbience>();
	

	void Awake() {
		if (core == null) {
			core = this;
		}
	}

}

[System.Serializable]
public class items {

	[Tooltip("Item name.")]
	public string name;

	[Space(10)][Tooltip("A unique item id.")]
	public int id;

	[Space(10)][Tooltip("Has the player acquired at least x1 of the item ?")]
	public bool acquired;

	[Space(10)][Tooltip("The name of function to be called from itemActions.cs on use event (The use event is triggered when the player clicks on the \"use\" button in the inventory.")]
	public string useFunction;
	
	[Space(10)][Tooltip("How many units of the item does the player have ?")]
	public int quantity;

	[Space(10)][Tooltip("Item description.")][TextArea]
	public List<string> examineText = new List<string>();

	[Space(10)][Tooltip("With which items can the item be combined and what are the resultant items ?")]
	public List<combinations> combinations = new List<combinations>();

	//A list of instace ids (see item.cs) of items that have already been picked up
	//This list is used to maintain a sense of consistency throught the game
	[HideInInspector]
	public List<int> pickedUpInstanceIds = new List<int>();
}

[System.Serializable]
public class itemsMeta {
	
	[Space(10)][Tooltip("An existing item id.")]
	public int existingItemId;

	[Space(10)][Tooltip("Item icon to be displayed in the inventory.")]
	public Sprite icon;
}

[System.Serializable]
public class quests {

	[Space(10)][Tooltip("Name of quest.")]
	public string questName;

	[Space(10)][Tooltip("Quest id.")]
	public int questId;

	[Space(10)][Tooltip("Quest Description.")][TextArea]
	public string questDescription;

	[Space(10)][Tooltip("Has the player obtained the specific quest ?")]
	public bool questAcquired;

	[Space(10)][Tooltip("Has the player completed the quest ?")]
	public bool questCompleted;
}

[System.Serializable]
public class combinations {

	[Tooltip("The id (in the database) of an item that the original should be combined with.")]
	public int itemId;

	[Space(10)][Tooltip("The id of the item that will result from the combination.")]
	public int productId;

	[Space(10)][Tooltip("Should the original item be destroyed on combination success ?")]
	public bool destroyPrimaryOnSuccess;

	[Space(10)][Tooltip("Should the secondary item be destroyed on success ?")]
	public bool destroySecondaryOnSuccess;
}

[System.Serializable]
public class entities {
	
	[Tooltip("A unique entity id.")]
	public int entityId;

	[Space(10)][Tooltip("The id of the current entity's stage (used to progress interactions).")]
	public int entityStageId;

	[Space(10)][Tooltip("Name of entity.")]
	public string entityName;
}

[System.Serializable]
public class journal {
	
	[Tooltip("Name of the entity which spawned the dialogue line.")]
	public string name;

	[Space(10)][Tooltip("The dialogue line spawned by the entity.")]
	public string entry;
}

[System.Serializable]
public class locations {
	[Tooltip("Name of location (level).")]
	public string name;
	
	[Space(10)][Tooltip("A unique location id.")]
	public int id;

	[Space(10)][Tooltip("The index of the location (level) in the build settings.")]
	public int buildSettingsIndex;
}

[System.Serializable]
public class stepSound {
	[Tooltip("ID of audioClip.")]
	public int id;
	[Tooltip("audioClip.")]
	public AudioClip clip;
}

[System.Serializable]
public class backgroundMusic {
	[Tooltip("Music id.")]
	public int id;

	[Tooltip("audioClip.")]
	public AudioClip clip;
}

[System.Serializable]
public class backgroundAmbience {
	[Tooltip("Ambience id.")]
	public int id;
	
	[Tooltip("audioClip.")]
	public AudioClip clip;
}

//Tsenkilidis Alexandros - Cination