﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class InventoryGenerator : MonoBehaviour {

		//item inventory prefab
		public GameObject itemPrefab;

		//currently selected item
		private items selectedItem;

		//is combination in progress?
		private bool combining;

		public void gen () {
			//getting content gameobject reference
			var content = ReferenceHolder.core.InventoryScrollViewContent;

			//clear children before spawning new ones (to avoid dupes)
			SupportFunctions.core.clear(content);

			//reseting selected
			selectedItem = null;

			//closing tool menu
			ReferenceHolder.core.InventoryToolsObject.SetActive(false);

			//getting inventory items
			foreach (items i in Database.core.items) {
				//if item is in the inventory
				if (i.acquired && i.quantity > 0) {
					//create instance
					GameObject instance = Instantiate(itemPrefab, content.transform);
					//icon
					if (SupportFunctions.core.findItemMetaIndexById(i.id) != -1 && Database.core.itemsMeta.Count >= (SupportFunctions.core.findItemMetaIndexById(i.id) + 1)) {
						instance.GetComponent<Image>().sprite = Database.core.itemsMeta[SupportFunctions.core.findItemMetaIndexById(i.id)].icon;
					}
					
					//quantity
					instance.transform.GetChild(1).GetComponent<Text>().text = "x" + i.quantity.ToString();

					//on click listener
					attachListener (i, instance);

				}
			}
		}

		void attachListener (items item, GameObject instance) {
			//getting button component
			var button = instance.GetComponent<Button>();
			//adding listener
			button.onClick.AddListener ( delegate { listenerContent(item, instance); } );
		}

		void listenerContent (items item, GameObject instance) {
			//are we combining items?
			if (!combining) {

				//marking item as selected - used for combining items
				selectedItem = item;
				//updating selected icon
				updateSelectedIcon (instance);
				//setting tool menu listeners
				setToolMenuListeners (item);
				//toggling tools menu
				ReferenceHolder.core.InventoryToolsObject.SetActive(true);
				
			} else {

				//can the two items be combined?
				foreach (combinations c in selectedItem.combinations) {
					//if yes,
					if (c.itemId == item.id) {
						//set the item in question as acquired
						var i = Database.core.items[SupportFunctions.core.findItemIndexById(c.productId)];
						i.acquired = true;
						i.quantity += 1;
						//display text
						combineText (i, true);
						//stop combining
						combining = false;

						//should the components be destroyed?
						//component 1
						if (c.destroyPrimaryOnSuccess) {
							if (selectedItem.quantity > 1) {
								//if we have more than one
								selectedItem.quantity -= 1;
							} else {
								//if we have one or less
								selectedItem.quantity = 0;
								selectedItem.acquired = false;
							}
						}

						//component 2
						if (c.destroySecondaryOnSuccess) {
							if (item.quantity > 1) {
								item.quantity -= 1;
							} else {
								item.quantity = 0;
								item.acquired = false;
							}
						}

						//regen inventory
						gen();
						//break the loop
						break;
					}
				}

				//did we get a result?
				if (combining) {
					//no
					combineText(null, false);
					//stop combining
					combining = false;
				}
			}
			
		}

		//combination result notification
		void combineText (items i, bool success) {

			var examineArea = ReferenceHolder.core.ExamineArea.transform.GetChild(0).gameObject;

			if (success) {
				//setting text
				examineArea.GetComponent<Text>().text = "You made \"" + i.name + "\"";
			} else {
				examineArea.GetComponent<Text>().text = "No result";
			}

			examineArea.GetComponent<Button>().onClick.RemoveAllListeners();
			//closing examine area
			examineArea.GetComponent<Button>().onClick.AddListener ( delegate { examineClose(); } );

			ReferenceHolder.core.ExamineArea.SetActive(true);
			//making sure that player cannot interact with objects or move
			ItemInteractionManager.core.playerCanInteract = false;
			EntityInteractionManager.core.playerCanInteract = false;
			Movement.core.playerCanMove = false;
			
		}

		void setToolMenuListeners (items item) {
			foreach (Transform child in ReferenceHolder.core.InventoryToolsObject.transform) {
				//removing old listeners
				child.GetComponent<Button>().onClick.RemoveAllListeners();
			}

			//setting new listeners
			var use = ReferenceHolder.core.InventoryToolsObject.transform.GetChild(0).gameObject.GetComponent<Button>();
			var examine = ReferenceHolder.core.InventoryToolsObject.transform.GetChild(1).gameObject.GetComponent<Button>();
			var combine = ReferenceHolder.core.InventoryToolsObject.transform.GetChild(2).gameObject.GetComponent<Button>();

			//use event
			use.onClick.AddListener ( delegate { 
				if (item.useFunction.Length > 0) { 
					ItemActions.core.Invoke (item.useFunction, 0f); //calling custom functions
				} 
				} ); 
			//examine event
			examine.onClick.AddListener ( delegate { examineAction (item); } );
			//combining two items
			combine.onClick.AddListener ( delegate { combineAction (item); } );
		}

		void examineAction (items item) {

			//getting gameobject
			var examineArea = ReferenceHolder.core.ExamineArea.transform.GetChild(0).gameObject;

			//removing old listeners
			examineArea.GetComponent<Button>().onClick.RemoveAllListeners();

			if (item.examineText.Count > 0) {
				//adding listeners for each line of text
				examineArea.GetComponent<Text>().text = item.examineText[0];
				examineArea.GetComponent<Button>().onClick.AddListener ( delegate { chainText (item.examineText, 1, examineArea); } );

			} else {
				///setting text
				examineArea.GetComponent<Text>().text = "I don't know anything about this item.";
				//closing on click
				examineArea.GetComponent<Button>().onClick.AddListener( delegate { examineClose(); } );
			}
			
			//enabling examine area
			ReferenceHolder.core.ExamineArea.SetActive(true);
			//making sure that player cannot interact with objects or move while examinning
			ItemInteractionManager.core.playerCanInteract = false;
			EntityInteractionManager.core.playerCanInteract = false;
			Movement.core.playerCanMove = false;
		}

		//combining items
		void combineAction (items item) {

			//letting the engine know that we are combining two items
			combining = true;
		}

		//Displaying text
		void chainText (List<string> s, int nextIndex, GameObject examineArea) {

			examineArea.GetComponent<Button>().onClick.RemoveAllListeners();

			if ((nextIndex) >= s.Count) {
				//closing area if count exceeded
				examineClose();
			} else {
				//setting text
				examineArea.GetComponent<Text>().text = s[nextIndex];
				//calling function recursivelly
				examineArea.GetComponent<Button>().onClick.AddListener ( delegate { chainText (s, nextIndex + 1, examineArea); } );
			}
			

		}

		void examineClose () {
			//closing object
			ReferenceHolder.core.ExamineArea.SetActive(false); 
			//allowing player to interact and move again
			ItemInteractionManager.core.playerCanInteract = true;
			EntityInteractionManager.core.playerCanInteract = true;
			Movement.core.playerCanMove = true;
		}

		void updateSelectedIcon (GameObject selectedItemObject) {
			var content = ReferenceHolder.core.InventoryScrollViewContent;

			foreach (Transform c in content.transform) {
				c.GetChild(2).gameObject.SetActive(false);
			}

			selectedItemObject.transform.GetChild(2).gameObject.SetActive(true);
		}

		void Update() {
			if (!ReferenceHolder.core.Inventory.activeSelf) {
				if (combining) {
					combining = false;
				}
			}
		}
}

//Tsenkilidis Alexandros - Cination