﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.SceneManagement;
using UnityEngine.UI;

public class ItemInteractionManager : MonoBehaviour {

	public static ItemInteractionManager core;

	[Tooltip("Can the player interact with items ?")]
	public bool playerCanInteract = true;

	[Tooltip("Default x position of the pop-up.")]
	public float defaultPopUpX = 1235f;
	[Tooltip("Goal (final) x position of the pop-up.")]
	public float goalPopUpX = 685f;

	[Tooltip("How long should the pop-up stay on the screen (excluding transitions) ?")]
	public float popUpStayTime = 2f;

	[Tooltip("How fast does the pop-up move ?")]
	public float popUpSpeed = 5f;

	[Tooltip("The furthest the item can be to still be interactable.")]
	public float maximumDistanceFromPlayer = 5f;
	
	//coroutine used to show item pop up
	Coroutine popUpRoutine;

	//picking up items
	public void pickUpItem (RaycastHit2D h) {

		//getting gameObject
		GameObject pickUpObject = h.collider.gameObject;

		//get player
		GameObject player = GameObject.FindWithTag("Player");

		//check distance to item
		var distance = Vector2.Distance(player.transform.position, pickUpObject.transform.position);
		
		if (distance <= maximumDistanceFromPlayer) {
			
			//item id
			int id = pickUpObject.GetComponent<Item>().id;
			//instance id
			int instanceId = pickUpObject.GetComponent<Item>().instanceId;

			//check if object can be picked up		
			if (pickUpObject.GetComponent<Item>().canBePickedUp) {
				var itemIndex = SupportFunctions.core.findItemIndexById (id);
				//check id validity
				if (itemIndex != -1) {
					//Getting the item
					Database.core.items[itemIndex].acquired = true;
					//increasing the quantity
					Database.core.items[itemIndex].quantity += 1;
					//adding location to item's dispawn list to make sure that the item will not appear when/if the level is loaded again
					Database.core.items[itemIndex].pickedUpInstanceIds.Add(instanceId);
					//Destroy GameObject from scene
					Destroy (pickUpObject);
					//hide item label
					SupportFunctions.core.displayName(null, true);

					//finally displaying item
					showPopUp (Database.core.items[itemIndex].name);

				} else {
					Debug.Log ("Wrong item id.");
				}
			}
		}
	}

	//initiating coroutine
	void showPopUp (string name) {
		//resetting popUpText and position
		ReferenceHolder.core.PopUp.transform.GetChild(0).gameObject.GetComponent<Text>().text = "Picked up \"" + name + "\"";

		var pos = ReferenceHolder.core.PopUp.transform.localPosition;
		ReferenceHolder.core.PopUp.transform.localPosition = new Vector3 (defaultPopUpX, pos.y, pos.z);

		//stopping previous coroutine if there was one
		if (popUpRoutine != null) {
			StopCoroutine (popUpRoutine);
		}
		//starting coroutine
		popUpRoutine = StartCoroutine (popUpShower ());

	}

	//This script is responsible for showing the pop up
	//feel free to modify this script for your pop up
	IEnumerator popUpShower () {

		//showing popUp
		while (ReferenceHolder.core.PopUp.transform.localPosition.x > goalPopUpX) {
			var pos = ReferenceHolder.core.PopUp.transform.localPosition;
			Vector3 newPos =  new Vector3 (pos.x -= popUpSpeed, pos.y, pos.z);
			ReferenceHolder.core.PopUp.transform.localPosition = newPos;
			yield return new WaitForSeconds (0.01f);
		}

		//Making sure we are exactly at the goal
		var pos2 = ReferenceHolder.core.PopUp.transform.localPosition;
		ReferenceHolder.core.PopUp.transform.localPosition = new Vector3 (goalPopUpX, pos2.y, pos2.z);

		//waiting before reversing
		yield return new WaitForSeconds (popUpStayTime);
		//reversing the animation
		while (ReferenceHolder.core.PopUp.transform.localPosition.x < defaultPopUpX) {
			var pos = ReferenceHolder.core.PopUp.transform.localPosition;
			Vector3 newPos =  new Vector3 (pos.x += popUpSpeed, pos.y, pos.z);
			ReferenceHolder.core.PopUp.transform.localPosition = newPos;
			yield return new WaitForSeconds (0.01f);
		}

		//same adjustments as before
		var pos3 = ReferenceHolder.core.PopUp.transform.localPosition;
		ReferenceHolder.core.PopUp.transform.localPosition = new Vector3 (defaultPopUpX, pos3.y, pos3.z);
		
	}

	void Awake() {
		if (core == null) {
			core = this;
		}
	}

}

//Tsenkilidis Alexandros - Cination
