﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;
using UnityEngine.SceneManagement;

//This script is responsible for loading levels
//I highly recommend customizing this script to fit your game
//Whenever calling this script from another script, make sure to adjust the spawnCoordinates of the player to fit the level to be loaded
//Only one instance of this script should exist. If you wish to use multiple instances of this script accross one scene, I recommend removing the script reference (core)
public class LevelLoader : MonoBehaviour {

	//making script accessible from other scripts
	public static LevelLoader core;

	[Tooltip("Fade effecr speed.")]
	public float fadeSpeed = 0.01f;

	[Space(10)][Tooltip("Location name label fade effect speed.")]
	public float labelFadeSpeed = 0.01f;

	[Space(10)][Tooltip("The amount of time the location name label is displayed for.")]
	public float locationLabelDisplayTime = 2f;

	//fade coroutine
	Coroutine fadeRoutine;

	//player coordinates on new scene
	//This line should be changed by script or hand for each scene
	[HideInInspector]
	public Vector2 spawnCoordinates = new Vector2 ();

	//this function is to be called when loading a level
	//Note: level id is the id of the level in the database, not the build settings index
	public void load (int levelId, bool loadingSave, PlayerData data) {

		//let's find build settings index
		var index = SupportFunctions.core.findBuildSettingsIndexById(levelId);
		//lets find location name
		var name = SupportFunctions.core.findLocationNameById(levelId);

		if (index != -1) {

			if (fadeRoutine != null) {
				StopCoroutine (fadeRoutine);
			}

			fadeRoutine = StartCoroutine (fader (index, name, loadingSave, data));

		} else {
			Debug.Log ("Invalid level id");
		}

		
	}

	//fader
 	IEnumerator	fader (int levelIndex, string levelName, bool loadingSave, PlayerData data) {

		//getting location label
		var locLabel = ReferenceHolder.core.locationName;

		//making sure the object is disabled
		locLabel.SetActive(false);

		//getting fade screen
		var fadeScreen = ReferenceHolder.core.FadeScreen;

		//making fade screen transparent
		Color c = fadeScreen.GetComponent<Image>().color;
		c.a = 0f;
		fadeScreen.GetComponent<Image>().color = c;

		//activating screen
		fadeScreen.SetActive(true);

		//turning fade screen to black
		while (c.a < 1) {
			c.a += fadeSpeed;
			fadeScreen.GetComponent<Image>().color = c;
			yield return new WaitForSeconds (0.01f);
		}
		
		//loading
		SceneManager.LoadScene(levelIndex, LoadSceneMode.Single);

		//changing player coordinates
		if (!loadingSave) {

			var player = GameObject.FindWithTag("Player");
			Vector3 newCoordinates = new Vector3 (spawnCoordinates.x, spawnCoordinates.y, player.transform.position.z);
			player.transform.position = newCoordinates;

		} else {

			//stopping player movement
			Movement.core.StopMovement(true);

			//changing player coordinates
			var playerZ = GameObject.FindWithTag("Player").transform.position.z;
			GameObject.FindWithTag("Player").transform.position = new Vector3 (data.player_x, data.player_y, playerZ);
		}
		
		//making screen transparent
		while (c.a > 0) {
			c.a -= fadeSpeed;
			fadeScreen.GetComponent<Image>().color = c;
			yield return new WaitForSeconds (0.01f);
		}

		//disabling screen
		fadeScreen.SetActive(false);

		//wait time before showing label
		yield return new WaitForSeconds (1f);

		//lastly, showing Name Label

		//setting text
		locLabel.GetComponent<Text>().text = levelName;

		Color c2 = locLabel.GetComponent<Text>().color;
		c2.a = 0;

		//setting opacity to 0
		locLabel.GetComponent<Text>().color = c2;

		//enabling object
		locLabel.SetActive(true);

		//fading
		while (c2.a < 1) {
			c2.a += labelFadeSpeed;
			locLabel.GetComponent<Text>().color = c2;
			yield return new WaitForSeconds (0.01f);
		}

		//displaying before returning to transparent
		yield return new WaitForSeconds (locationLabelDisplayTime);

		//making transparent again
		while (c2.a > 0) {
			c2.a -= labelFadeSpeed;
			locLabel.GetComponent<Text>().color = c2;
			yield return new WaitForSeconds (0.01f);
		}

		//disabling object
		locLabel.SetActive(false);
		
	}

	void Awake () {
		if (core == null) {
			core = this;
		}
	}
}

//Tsenkilidis Alexandros - Cination