﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

//This script should be attached to a LevelManager (tagged as so) object on each level, as it initiates crucial variables
//Note: This script can and should be customized to fit your own project
public class LevelManager : MonoBehaviour {

	//reference
	public static LevelManager core;

	[Tooltip("ID of the step sound to be used for this level, in the Database.cs.")]
	public int stepSoundId;

	[Tooltip("ID of the background ambient sound, in the Database.cs.")]
	public int backgroundAmbienceId;

	[Tooltip("ID of the background music, in the Database.cs.")]
	public int backgroundMusicId;

	//play ambience and music ?
	public bool playBackgroundMusic;
	public bool playAmbience;

	//audioSource (s) are initiated in order to allow easy deletion / management
	AudioSource musicSource;
	AudioSource ambienceSource;

	//Once everything has been loaded
	void Start () {
		
		if (playBackgroundMusic) {
			musicSource = gameObject.AddComponent<AudioSource>();
			musicSource.clip = Database.core.music[SupportFunctions.core.findMusicClipIndexById(backgroundMusicId)].clip;
			musicSource.loop = true;
			musicSource.Play();
		}

		if (playAmbience) {
			ambienceSource = gameObject.AddComponent<AudioSource>();
			ambienceSource.clip = Database.core.ambience[SupportFunctions.core.findAmbienceClipIndexById(backgroundAmbienceId)].clip;
			ambienceSource.loop = true;
			ambienceSource.Play();
		}
	}

	//initiation
	void Awake () {
		if (core == null) {
			core = this;
		}
	}

}

//Tsenkilidis Alexandros - Cination