﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

//This script generates the quests
public class QuestGenerator : MonoBehaviour {

	public GameObject questPrefab;

	//default action to generate all acquired quests
	public void genAll () {
		//removing old quests
		SupportFunctions.core.clear(ReferenceHolder.core.QuestScrollViewContent);
		//disabling inspector
		ReferenceHolder.core.QuestInspectorWindow.SetActive(false);

		//generating all quests
		foreach (quests q in Database.core.quests) {
			if (q.questAcquired) {
				//create prefab instance
				GameObject instance = Instantiate (questPrefab, ReferenceHolder.core.QuestScrollViewContent.transform);
				//set text
				instance.transform.GetChild(0).gameObject.GetComponent<Text>().text = q.questName;

				//distinguishing completed quests
				if (q.questCompleted) {
					instance.GetComponent<Image>().color = new Color32 (156, 231, 159, 255);
				}

				//add listener
				setQuestListener (q, instance);
			}
		}
	}
	
	public void genActive () {
		//removing old quests
		SupportFunctions.core.clear(ReferenceHolder.core.QuestScrollViewContent);
		//disabling inspector
		ReferenceHolder.core.QuestInspectorWindow.SetActive(false);

		//generating active quests
		foreach (quests q in Database.core.quests) {
			if (q.questAcquired && !q.questCompleted) {
				//create prefab instance
				GameObject instance = Instantiate (questPrefab, ReferenceHolder.core.QuestScrollViewContent.transform);
				//set text
				instance.transform.GetChild(0).gameObject.GetComponent<Text>().text = q.questName;
				//add listener
				setQuestListener (q, instance);
			}
		}

	}

	public void genCompleted () {
		//removing old quests
		SupportFunctions.core.clear(ReferenceHolder.core.QuestScrollViewContent);
		//disabling inspector
		ReferenceHolder.core.QuestInspectorWindow.SetActive(false);

		//generating all quests
		foreach (quests q in Database.core.quests) {
			if (q.questAcquired && q.questCompleted) {
				//create prefab instance
				GameObject instance = Instantiate (questPrefab, ReferenceHolder.core.QuestScrollViewContent.transform);
				//set text
				instance.transform.GetChild(0).gameObject.GetComponent<Text>().text = q.questName;
				//add listener
				setQuestListener (q, instance);

			}
		}

	}

	//this function attached a listener to a quest button
	void setQuestListener (quests q, GameObject g) {
		//getting button
		Button b = g.GetComponent<Button>();
		//adding listener to inpsect quests
		b.onClick.AddListener ( delegate { openQuestInspector (q); } );

	}

	void openQuestInspector (quests q) {
		//getting inspector window
		GameObject inspector = ReferenceHolder.core.QuestInspectorWindow;
		//getting label
		GameObject label = ReferenceHolder.core.QuestInspectorLabel;
		//getting description
		GameObject description = ReferenceHolder.core.QuestInspectorDescription;

		//setting label
		label.GetComponent<Text>().text = q.questName;
		//setting description
		description.GetComponent<Text>().text = q.questDescription;
		//openning the inspector
		inspector.SetActive(true);
	}
}

//Tsenkilidis Alexandros - Cination