﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;
using System;
using System.IO;
using System.Runtime.Serialization.Formatters.Binary;
using UnityEngine.SceneManagement;

public class SaveLoad : MonoBehaviour {

	//Loading data from file
	public void Load (string savename) {

		savename = "/" + savename;

		//Does the save file even exist ?
		if (File.Exists (Application.persistentDataPath + savename)) {

			//If it does, deserialize file.
			BinaryFormatter binform = new BinaryFormatter ();
			FileStream file = File.Open (Application.persistentDataPath + savename, FileMode.Open);
			PlayerData data = (PlayerData) binform.Deserialize (file);
			file.Close ();

			//Extracting data

			//Loading level if current level is different than the save level
			LevelLoader.core.load (data.saveLevel, true, data);

			//loading database lists
			Database.core.quests = data.quests;
			Database.core.journal = data.journal;
			Database.core.items = data.items;
			Database.core.entities = data.entities;
		}
	}

	//Saving data to file
	public void Save (string filename) {


		//Creating and writing file
		BinaryFormatter binform = new BinaryFormatter();

		FileStream file = File.Create (Application.persistentDataPath + "/" + filename);

		//Creating an instance of the data class
		PlayerData data = new PlayerData ();

		//Writing info to "data".
		data.quests = Database.core.quests;
		data.journal = Database.core.journal;
		data.items = Database.core.items;
		data.entities = Database.core.entities;

		//finding id of current level
		data.saveLevel = SupportFunctions.core.findIdByBuildSettingsIndex(SceneManager.GetActiveScene().buildIndex);

		var playerCoordinates = GameObject.FindWithTag("Player").transform.position;
		data.player_x = playerCoordinates.x;
		data.player_y = playerCoordinates.y;

		//Writting class to file
		binform.Serialize (file, data);

		file.Close ();

	}

	

}

[Serializable]
public class PlayerData {

	//The following data will be saved and loaded
	public int saveLevel;

	public float player_x;
	public float player_y;

	public List<items> items {get; set;}
	public List<entities> entities {get; set;}
	public List<journal> journal {get; set;}
	public List<quests> quests {get; set;}

}

//Tsenkilidis Alexandros - Cination