﻿
using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class Speech : MonoBehaviour {

	public static Speech core;

	[Tooltip("Speech bubble prefab.")]
	public GameObject speechBubble;


	//This function is to be called to generate text
	public void genText (nodes node, int stageIndex, GameObject scriptSource) {	

		GameObject source;

		//if player is the one talking, finding the player text target object
		if (node.playerIsTalking) {
			source = GameObject.FindWithTag("playerTextPoint");
		} else {
			source = node.textTarget;
		}
		
		string s = node.text;
		float duration = node.textDuration;
		bool showNextNode = node.goToNodeOnClick;
		int nextNodeId = node.goToNodeId;
		bool waitForClick = node.waitForClick;
		bool showOptions = node.displayOptions;


		//removing existing text (if neccessary)
		foreach (Transform child in GameObject.FindWithTag("speechHolder").transform) {
			//Make sure that no two object on the scene have the same name.
			if (child.name == source.name) {
				Destroy (child.gameObject);
			}	
		}

		Vector3 coordinates = source.transform.position;
		GameObject instance = Instantiate(speechBubble, coordinates, Quaternion.identity, GameObject.FindWithTag("speechHolder").transform);

		//audio
		var audioSource = instance.AddComponent<AudioSource>();

		//if audio is to be played
		if (node.playAudioWithText) {
			audioSource.clip = node.audio;
			audioSource.loop = false;
			audioSource.Play();
		}

		//setting text
		instance.GetComponent<Text>().text = s;
		instance.name = source.name;
		
		
		if (!waitForClick) { //starting routines
			StartCoroutine (killOff(instance, duration, source, showNextNode, nextNodeId, stageIndex, scriptSource));
		}

		//handling options
		if (showOptions) {
			StartCoroutine (optionsCheck(instance, scriptSource, node));
		}
		
		StartCoroutine (adjustPosition(instance,source));

		//adding click listener for killoff
		Button clickCatcher = ReferenceHolder.core.ClickCatcher.GetComponent<Button>();
		clickCatcher.onClick.AddListener (delegate { clickKill (instance, source); });
		
	}

	private void clickKill (GameObject instance, GameObject source) {
		if (instance != null) {
			Destroy(instance);
		}
	}

	//If options were displayed, once any of the options has been selected, despawn the instance
	IEnumerator optionsCheck (GameObject instance, GameObject scriptSource, nodes node) {

		var found = false;
		while (!found) {
			yield return new WaitForEndOfFrame();

			foreach (int i in node.optionsIds) {
				if (scriptSource.GetComponent<Entity>().options[SupportFunctions.core.findOptionIndexById(i, scriptSource)].selected) {
					//regardless of whether we dispawned the instance or not, we want to "deselect" all options to avoid possible future bugs.
					scriptSource.GetComponent<Entity>().options[SupportFunctions.core.findOptionIndexById(i, scriptSource)].selected = false;
					if (!found) {
						if (instance != null) {
							Destroy(instance);
						}
						found = true;
					}
				}
			}
		}

		

	}
	IEnumerator killOff (GameObject instance, float duration, GameObject source, bool showNextNode, int nextNodeId, int stageIndex, GameObject scriptSource) {
		yield return new WaitForSeconds (duration);
		
		if (instance != null) {
			//show next node
			if (showNextNode) {
				scriptSource.GetComponent<Entity>().dialogueEngine(1, stageIndex, -1, nextNodeId);
			}
			Destroy(instance);
		}
	}

	IEnumerator adjustPosition (GameObject instance, GameObject source) {
		while (instance != null) {
			instance.transform.position = source.transform.position;
			yield return new WaitForSeconds (0.01f);
		}
	}
	
	void Awake() {
		if (core == null) {
			core = this;
		}
	}
}

//Tsenkilidis Alexandros - Cination